@@ -1,7 +1,7 @@
-/* 	$Id: ssl.c,v 1.7 1996/02/01 11:57:42 martin Exp $	 */
+/* 	$Id: ssl.c,v 1.8 1996/06/13 14:13:18 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: ssl.c,v 1.7 1996/02/01 11:57:42 martin Exp $";
+static char vcid[] = "$Id: ssl.c,v 1.8 1996/06/13 14:13:18 martin Exp $";
 #endif /* lint */
 
 #include "../../config.h"
@@ -383,14 +383,7 @@ int level;
 	    fclose(user_fp);
 	    return(AUTH_USER);
 	} else {
-	    /* we force the user to provide a password (over the
-	     * encrypted channel to do "normal" authentication
-	     */
-	  /*	    if (UserNameRequested && auth_ssl_valid) {
-		    strcpy(name, UserNameRequested);
-		    return(AUTH_VALID);
-	    } else*/
-		    return(AUTH_USER);
+	    return(AUTH_USER);
 	}
 }
 
