@@ -40,10 +40,10 @@ static char sccsid[] = "@(#)sys_bsd.c	8.2 (Berkeley) 12/15/93";
  * (at least between 4.x and dos) which is used in telnet.c.
  */
 
-/* 	$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $	 */
+/* 	$Id: sys_bsd.c,v 1.6 1996/02/01 12:07:12 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $";
+static char vcid[] = "$Id: sys_bsd.c,v 1.6 1996/02/01 12:07:12 martin Exp $";
 #endif /* lint */
 
 #include "../config.h"
@@ -63,9 +63,14 @@ static char vcid[] = "$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $";
 #if defined(HAVE_SYS_SELECT_H) && !defined(SCO)
 # include <sys/select.h>
 #endif
-#include <sys/socket.h>
+/*#if defined(__ultrix)
+# include <cxx/sys/socket.h>
+#else*/
+# include <sys/socket.h>
+/*#endif*/
 #include <signal.h>
 #include <errno.h>
+#include <unistd.h>
 #include <arpa/telnet.h>
 
 #include "ring.h"
@@ -76,6 +81,8 @@ static char vcid[] = "$Id: sys_bsd.c,v 1.3 1995/08/25 13:22:37 martin Exp $";
 #include "externs.h"
 #include "types.h"
 
+#include "../lib/libtelnet/misc-proto.h"
+
 #if	defined(CRAY) || (defined(USE_TERMIO) && !defined(SYSV_TERMIO))
 #define	SIG_FUNC_RET	void
 #else
@@ -967,8 +974,13 @@ sys_telnet_init()
  */
 
     int
-process_rings(netin, netout, netex, ttyin, ttyout, poll)
-    int poll;		/* If 0, then block until something to do */
+process_rings(netin,
+	      netout,
+	      netex,
+	      ttyin,
+	      ttyout,
+	      poll) /* If 0, then block until something to do */
+    int netin, netout, netex, ttyin, ttyout, poll;
 {
     register int c;
 		/* One wants to be a bit careful about setting returnValue
